@@ -1,7 +1,7 @@
 /*
-  $Id: tokenize.cxx 13652 2011-12-06 16:44:23Z sloot $
+  $Id: tokenize.cxx 13916 2012-01-09 15:54:11Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/ucto/trunk/src/tokenize.cxx $
-  Copyright (c) 2006 - 2011
+  Copyright (c) 2006 - 2012
   Tilburg University
 
   This file is part of Ucto
@@ -115,8 +115,10 @@ namespace Tokenizer {
     UParseError errorInfo;
     pattern = RegexPattern::compile( pat, 0, errorInfo, u_stat );
     if ( U_FAILURE(u_stat) ){
-      failString = "Invalid regular expression '" + folia::UnicodeToUTF8(pat) +
-	"', no compiling possible";	
+      failString = "Invalid regular expression '" + folia::UnicodeToUTF8(pat)
+	+ "' ";
+      if ( errorInfo.offset >0 )
+	failString += ", at position " + toString( errorInfo.offset );	
       throw uConfigError(failString);
     }
     else {
